@@ -2,6 +2,10 @@
 
 set -vex
 
+sudo apt-get update
+sudo apt-get install -y clang libharfbuzz0b git curl zip unzip tar bison gperf libx11-dev libxft-dev libxext-dev \
+	libgles2-mesa-dev autoconf libtool build-essential libxrandr-dev libxi-dev libxcursor-dev libxdamage-dev libxinerama-dev
+
 export VCPKG_ROOT="$HOME/build/vcpkg"
 if [[ -e "$VCPKG_ROOT" && ! -e "$VCPKG_ROOT/.git" ]]; then
 	rm -rf "$VCPKG_ROOT"
@@ -18,7 +22,6 @@ git checkout "$VCPKG_TREE_COMMIT"
 echo "set(VCPKG_BUILD_TYPE release)" >> triplets/x64-linux.cmake
 export VCPKG_DEFAULT_TRIPLET=x64-linux
 #./vcpkg install llvm  # takes very long time
-sudo apt-get install -y clang libharfbuzz0b
 # workaround to make clang_sys crate detect installed libclang
 sudo ln -s libclang.so.1 /usr/lib/llvm-10/lib/libclang.so
 ./vcpkg upgrade --no-dry-run
