@@ -20,7 +20,7 @@
 
 #define CODE_CATCH(return_type, exc_type, code, msg) \
 catch (exc_type) { \
-	return Err<return_type>(code, msg); \
+	Err<return_type>(code, msg, ocvrs_return); \
 }
 
 #define OCVRS_CATCH(return_type) \
@@ -45,20 +45,21 @@ struct Result_void {
 	void* error_msg;
 };
 
-template<typename T> inline Result<T> Ok(T result) {
-	return Result<T> { 0, 0, result };
+template<typename T, typename R> inline void Ok(T result, Result<R>* ocvrs_return) {
+	ocvrs_return->error_code = 0;
+	ocvrs_return->error_msg = NULL;
+	ocvrs_return->result = *const_cast<R*>(&result);
 }
 
-inline Result_void Ok() {
-	return Result_void { 0, 0 };
+inline void Ok(Result_void* ocvrs_return) {
+	ocvrs_return->error_code = 0;
+	ocvrs_return->error_msg = NULL;
 }
 
-template<typename T> inline T Err(int code, const char* msg) {
-	unsigned char ret_buf[sizeof(T)] = {};
-	T ret = *reinterpret_cast<T*>(&ret_buf);
-	ret.error_code = code;
-	ret.error_msg = ocvrs_create_string(msg);
-	return ret;
+template<typename T> inline void Err(int code, const char* msg, T* ocvrs_return) {
+	ocvrs_return->error_code = code;
+	ocvrs_return->error_msg = ocvrs_create_string(msg);
+	// it's ok to leave result uninitialized because the Rust implementation only assumes it as init if error_msg is NULL
 }
 
 #endif
