@@ -1,7 +1,7 @@
 use matches::assert_matches;
 
 use opencv::{
-	core::{self, Matx12d, Scalar, ToInputArray, UMat, UMatUsageFlags},
+	core::{self, Matx12d, Scalar, ToInputArray, ToInputOutputArray, ToOutputArray, UMat, UMatUsageFlags, Vec2b, VecN},
 	prelude::*,
 	Result,
 	types::{VectorOff64, VectorOfu8},
@@ -22,9 +22,32 @@ fn input_array() -> Result<()> {
 #[test]
 fn input_output_array_types() -> Result<()> {
 	assert!(Mat::default().input_array()?.is_mat()?);
+	assert!(Mat::default().output_array()?.is_mat()?);
+	assert!(Mat::default().input_output_array()?.is_mat()?);
+
 	assert!(VectorOfu8::new().input_array()?.is_vector()?);
+	assert!(VectorOfu8::new().output_array()?.is_vector()?);
+	assert!(VectorOfu8::new().input_output_array()?.is_vector()?);
+
 	assert!(Matx12d::default().input_array()?.is_matx()?);
+	assert!(Matx12d::default().output_array()?.is_matx()?);
+	assert!(Matx12d::default().input_output_array()?.is_matx()?);
+
 	assert!(UMat::new_rows_cols_with_default(1, 1, u8::typ(), Scalar::from(8.), UMatUsageFlags::USAGE_DEFAULT)?.input_array()?.is_umat()?);
+	assert!(UMat::new_rows_cols_with_default(1, 1, u8::typ(), Scalar::from(8.), UMatUsageFlags::USAGE_DEFAULT)?.output_array()?.is_umat()?);
+	assert!(UMat::new_rows_cols_with_default(1, 1, u8::typ(), Scalar::from(8.), UMatUsageFlags::USAGE_DEFAULT)?.input_output_array()?.is_umat()?);
+
+	assert!(Scalar::default().input_array()?.is_matx()?);
+	assert!(Scalar::default().output_array()?.is_matx()?);
+	assert!(Scalar::default().input_output_array()?.is_matx()?);
+
+	assert!(Vec2b::default().input_array()?.is_matx()?);
+	assert!(Vec2b::default().output_array()?.is_matx()?);
+	assert!(Vec2b::default().input_output_array()?.is_matx()?);
+
+	assert!(VecN::<f64, 18>::default().input_array()?.is_matx()?);
+	assert!(VecN::<f64, 18>::default().output_array()?.is_matx()?);
+	assert!(VecN::<f64, 18>::default().input_output_array()?.is_matx()?);
 	Ok(())
 }
 
